# PyTorch-Tao

[![image](https://github.com/louis-she/pytorch-tao/actions/workflows/test.yaml/badge.svg?branch=master)](https://github.com/louis-she/pytorch-tao/actions)
[![image](https://github.com/louis-she/pytorch-tao/actions/workflows/publish.yaml/badge.svg)](https://github.com/louis-she/pytorch-tao/actions)
[![image](https://img.shields.io/badge/dynamic/json.svg?label=PyPI&url=https%3A%2F%2Fpypi.org%2Fpypi%2Fpytorch-tao%2Fjson&query=%24.info.version&colorB=brightgreen&prefix=v)](https://pypi.org/project/pytorch-tao/)
[![codecov](https://codecov.io/github/louis-she/pytorch-tao/branch/master/graph/badge.svg?token=MBRMLX7REF)](https://codecov.io/github/louis-she/pytorch-tao)

PyTorch-Tao is a toolbox for a specific Machine Learning training project. It focus on the issues met in training process such as experiment management, reproducable etc.
